# IgnoredWords.jl
#
# Enumerates many of the words that should be ignored.

abstract EnumeratedWords;

type WordType <: EnumeratedWords
  val::Int;
  function WordType(ii::Integer)
    @assert 0 <= ii <= 4;
    new(ii);
  end
end  # WordType

const tURL = WordType(0);
const tURLString = "tURL";
const tPunctuation = WordType(1);  # Some types of punctuation
const tPunctuationString = "tPunctuation";
const tEmail = WordType(2);  # Email or twitter handle type
const tEmailString = "tEmail";
const tNumber = WordType(3);  # Numbers
const tNumberString = "tNumber";
const tOther = WordType(4);  # Not any of the others

# Compare word types
<(a::WordType, b::WordType) = (a.val < b.val);
isless(a::WordType, b::WordType) = (a.val < b.val);

function GetWordType(word::AbstractString)
  if ('@' in word)
    return tEmail;
  elseif (contains(word, "http"))
    return tURL;
  elseif (contains(word, "//"))
    return tURL;
  end
  m = match(r"[0-9\.\-]+", word);
  if (m != nothing && m.match == word)
    return tNumber;
  end
  reg_punct = r"[\?\.!\+,]";
  m = match(reg_punct, word);
  if (m != nothing && m.match == word)
    return tPunctuation;
  end
  return tOther;
end

